@@ -1,6 +1,6 @@
 import time
 
-class Output:
+class Output(object):
     def __init__(self):
         self.context = ''
         self.level = 0
