@@ -5,7 +5,7 @@ import time
 
 from dosage import util
 
-class Guess:
+class Guess(object):
     def __init__(self, weight):
         self.weight = weight
         self.guess = 0
@@ -17,7 +17,7 @@ class Guess:
     def distance(self, value):
         return (self.guess - value) ** 2
 
-class FortuneTeller:
+class FortuneTeller(object):
     weights = (0.2, 0.3, 0.4)
 
     def __init__(self):
